# ExotelPy
[![PyPI - Version](https://img.shields.io/pypi/v/exotelpy.svg)](https://pypi.org/project/exotelpy) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/exotelpy.svg)](https://pypi.org/project/exotelpy)

## Overview
exotelpy is an unofficial Python wrapper for the [Exotel API](https://developer.exotel.com/api), allowing developers to easily integrate Exotel's communication services into their Python applications. Exotel provides cloud-based communication solutions, including features like voice and SMS services.

## Documentation
Detailed documentation for exotelpy can be found [here.](https://noorahealth.github.io/exotel-python/)


## Installation
```
pip install exotelpy
```
